.. webapi-error::
   :title: Repository Action Not Supported
   :instance: reviewboard.webapi.errors.REPO_NOT_IMPLEMENTED

   The request made on a repository's resource can't be performed by that type
   of repository. That particular action is invalid for that repository type.
   There is no sense in retrying this request on the same repository.
